# PermissionName


## Enum

* `ORGANIZATION_READ` (value: `'organization_read'`)

* `ORGANIZATION_DELETE` (value: `'organization_delete'`)

* `ORGANIZATION_UPDATE` (value: `'organization_update'`)

* `ORGANIZATION_LIST_WORKSPACES` (value: `'organization_list_workspaces'`)

* `ORGANIZATION_CREATE_WORKSPACE` (value: `'organization_create_workspace'`)

* `ORGANIZATION_LIST_GROUP_MEMBERSHIPS` (value: `'organization_list_group_memberships'`)

* `ORGANIZATION_CREATE_USER` (value: `'organization_create_user'`)

* `ORGANIZATION_INVITE_USER` (value: `'organization_invite_user'`)

* `ORGANIZATION_CREATE_SERVICE_ACCOUNT` (value: `'organization_create_service_account'`)

* `DELETE_USER` (value: `'delete_user'`)

* `USER_UPDATE` (value: `'user_update'`)

* `ORGANIZATION_ROLE_BINDING_DELETE` (value: `'organization_role_binding_delete'`)

* `ORGANIZATION_CREATE_ROLE_BINDING` (value: `'organization_create_role_binding'`)

* `ORGANIZATION_LIST_ROLE_BINDINGS` (value: `'organization_list_role_bindings'`)

* `ORGANIZATION_LIST_USERS` (value: `'organization_list_users'`)

* `ORGANIZATION_CREATE_GROUP` (value: `'organization_create_group'`)

* `ORGANIZATION_LIST_GROUPS` (value: `'organization_list_groups'`)

* `ORGANIZATION_LIST_ROLES` (value: `'organization_list_roles'`)

* `GROUP_LIST_ROLE_BINDINGS` (value: `'group_list_role_bindings'`)

* `GROUP_READ` (value: `'group_read'`)

* `GROUP_LIST_USERS` (value: `'group_list_users'`)

* `GROUP_UPDATE` (value: `'group_update'`)

* `GROUP_DELETE` (value: `'group_delete'`)

* `GROUP_CREATE_GROUP_MEMBERSHIP` (value: `'group_create_group_membership'`)

* `GROUP_DELETE_GROUP_MEMBERSHIP` (value: `'group_delete_group_membership'`)

* `USER_LIST_ROLE_BINDINGS` (value: `'user_list_role_bindings'`)

* `USER_REGENERATE_CREDS` (value: `'user_regenerate_creds'`)

* `WORKSPACE_READ` (value: `'workspace_read'`)

* `WORKSPACE_UPDATE` (value: `'workspace_update'`)

* `WORKSPACE_DELETE` (value: `'workspace_delete'`)

* `WORKSPACE_LIST_PROJECTS` (value: `'workspace_list_projects'`)

* `WORKSPACE_CREATE_PROJECT` (value: `'workspace_create_project'`)

* `WORKSPACE_CREATE_DATA_PLANE` (value: `'workspace_create_data_plane'`)

* `WORKSPACE_LIST_DATA_PLANES` (value: `'workspace_list_data_planes'`)

* `WORKSPACE_LIST_DATA_PLANE_ASSOCIATIONS` (value: `'workspace_list_data_plane_associations'`)

* `WORKSPACE_CREATE_DATA_PLANE_ASSOCIATION` (value: `'workspace_create_data_plane_association'`)

* `WORKSPACE_ROLE_BINDING_DELETE` (value: `'workspace_role_binding_delete'`)

* `WORKSPACE_CREATE_ROLE_BINDING` (value: `'workspace_create_role_binding'`)

* `WORKSPACE_LIST_ROLE_BINDINGS` (value: `'workspace_list_role_bindings'`)

* `WORKSPACE_CREATE_WEBHOOK` (value: `'workspace_create_webhook'`)

* `WORKSPACE_LIST_WEBHOOKS` (value: `'workspace_list_webhooks'`)

* `WORKSPACE_TEST_WEBHOOK` (value: `'workspace_test_webhook'`)

* `WORKSPACE_CREATE_CUSTOM_AGGREGATION` (value: `'workspace_create_custom_aggregation'`)

* `WORKSPACE_VALIDATE_CUSTOM_AGGREGATION` (value: `'workspace_validate_custom_aggregation'`)

* `WORKSPACE_LIST_DATASETS` (value: `'workspace_list_datasets'`)

* `PROJECT_READ` (value: `'project_read'`)

* `PROJECT_UPDATE` (value: `'project_update'`)

* `PROJECT_DELETE` (value: `'project_delete'`)

* `PROJECT_LIST_MODELS` (value: `'project_list_models'`)

* `PROJECT_CREATE_MODEL` (value: `'project_create_model'`)

* `PROJECT_LIST_CONNECTORS` (value: `'project_list_connectors'`)

* `PROJECT_CREATE_CONNECTOR` (value: `'project_create_connector'`)

* `PROJECT_LIST_DATASETS` (value: `'project_list_datasets'`)

* `PROJECT_LIST_JOBS` (value: `'project_list_jobs'`)

* `PROJECT_CREATE_JOB` (value: `'project_create_job'`)

* `PROJECT_CREATE_DATASET` (value: `'project_create_dataset'`)

* `PROJECT_CREATE_AVAILABLE_DATASET` (value: `'project_create_available_dataset'`)

* `PROJECT_LIST_DATA_PLANE_ASSOCIATIONS` (value: `'project_list_data_plane_associations'`)

* `PROJECT_ROLE_BINDING_DELETE` (value: `'project_role_binding_delete'`)

* `PROJECT_CREATE_ROLE_BINDING` (value: `'project_create_role_binding'`)

* `PROJECT_LIST_ROLE_BINDINGS` (value: `'project_list_role_bindings'`)

* `PROJECT_GENERATE_METRICS_SPEC` (value: `'project_generate_metrics_spec'`)

* `PROJECT_CREATE_MODEL_TASK` (value: `'project_create_model_task'`)

* `PROJECT_CREATE_MODEL_LINK_TASK` (value: `'project_create_model_link_task'`)

* `MODEL_READ` (value: `'model_read'`)

* `MODEL_UPDATE` (value: `'model_update'`)

* `MODEL_DELETE` (value: `'model_delete'`)

* `MODEL_PUT_METRIC_CONFIG` (value: `'model_put_metric_config'`)

* `MODEL_LIST_METRIC_VERSIONS` (value: `'model_list_metric_versions'`)

* `MODEL_CREATE_METRIC_VERSION` (value: `'model_create_metric_version'`)

* `MODEL_ADD_METRICS_FOR_VERSION` (value: `'model_add_metrics_for_version'`)

* `MODEL_EDIT_DASHBOARD` (value: `'model_edit_dashboard'`)

* `MODEL_CREATE_ALERT` (value: `'model_create_alert'`)

* `MODEL_LIST_ALERTS` (value: `'model_list_alerts'`)

* `MODEL_CREATE_ALERT_RULE` (value: `'model_create_alert_rule'`)

* `MODEL_LIST_ALERT_RULES` (value: `'model_list_alert_rules'`)

* `MODEL_QUERY_METRICS` (value: `'model_query_metrics'`)

* `MODEL_METRICS_SCHEDULE_UPDATE` (value: `'model_metrics_schedule_update'`)

* `MODEL_METRICS_SCHEDULE_DELETE` (value: `'model_metrics_schedule_delete'`)

* `MODEL_TASK_READ` (value: `'model_task_read'`)

* `MODEL_TASK_UPDATE` (value: `'model_task_update'`)

* `MODEL_TASK_DELETE` (value: `'model_task_delete'`)

* `MODEL_TASK_SYNC` (value: `'model_task_sync'`)

* `MODEL_TASK_PUT_STATE_CACHE` (value: `'model_task_put_state_cache'`)

* `MODEL_TASK_PUT_CONNECTION_INFO` (value: `'model_task_put_connection_info'`)

* `MODEL_TASK_GET_CONNECTION_INFO` (value: `'model_task_get_connection_info'`)

* `MODEL_TASK_DELETE_CONNECTION_INFO` (value: `'model_task_delete_connection_info'`)

* `MODEL_TASK_REGENERATE_VALIDATION_KEY` (value: `'model_task_regenerate_validation_key'`)

* `CONNECTOR_READ` (value: `'connector_read'`)

* `CONNECTOR_UPDATE` (value: `'connector_update'`)

* `CONNECTOR_DELETE` (value: `'connector_delete'`)

* `CONNECTOR_GET_SENSITIVE_FIELDS` (value: `'connector_get_sensitive_fields'`)

* `CONNECTOR_PUT_CHECK_RESULT` (value: `'connector_put_check_result'`)

* `CONNECTOR_LIST_DATASETS` (value: `'connector_list_datasets'`)

* `CONNECTOR_CREATE_DATASET` (value: `'connector_create_dataset'`)

* `CONNECTOR_LIST_AVAILABLE_DATASETS` (value: `'connector_list_available_datasets'`)

* `CONNECTOR_PUT_AVAILABLE_DATASETS` (value: `'connector_put_available_datasets'`)

* `CONNECTOR_CREATE_AVAILABLE_DATASET` (value: `'connector_create_available_dataset'`)

* `AVAILABLE_DATASET_READ` (value: `'available_dataset_read'`)

* `AVAILABLE_DATASET_PUT_SCHEMA` (value: `'available_dataset_put_schema'`)

* `AVAILABLE_DATASET_CREATE_DATA_RETRIEVAL` (value: `'available_dataset_create_data_retrieval'`)

* `AVAILABLE_DATASET_GET_DATA_RETRIEVAL` (value: `'available_dataset_get_data_retrieval'`)

* `AVAILABLE_DATASET_PUT_DATA_RETRIEVAL` (value: `'available_dataset_put_data_retrieval'`)

* `AVAILABLE_DATASET_DELETE_DATA_RETRIEVAL` (value: `'available_dataset_delete_data_retrieval'`)

* `DATASET_READ` (value: `'dataset_read'`)

* `DATASET_UPDATE` (value: `'dataset_update'`)

* `DATASET_PUT_SCHEMA` (value: `'dataset_put_schema'`)

* `DATASET_DELETE` (value: `'dataset_delete'`)

* `DATASET_CREATE_DATA_RETRIEVAL` (value: `'dataset_create_data_retrieval'`)

* `DATASET_GET_DATA_RETRIEVAL` (value: `'dataset_get_data_retrieval'`)

* `DATASET_PUT_DATA_RETRIEVAL` (value: `'dataset_put_data_retrieval'`)

* `DATASET_DELETE_DATA_RETRIEVAL` (value: `'dataset_delete_data_retrieval'`)

* `PROJECT_JOB_READ` (value: `'project_job_read'`)

* `PROJECT_JOB_UPDATE` (value: `'project_job_update'`)

* `PROJECT_JOB_PUT_STATE` (value: `'project_job_put_state'`)

* `PROJECT_JOB_READ_LOGS` (value: `'project_job_read_logs'`)

* `PROJECT_JOB_READ_RUNS` (value: `'project_job_read_runs'`)

* `PROJECT_JOB_APPEND_LOGS` (value: `'project_job_append_logs'`)

* `PROJECT_JOB_READ_ERRORS` (value: `'project_job_read_errors'`)

* `PROJECT_JOB_APPEND_ERRORS` (value: `'project_job_append_errors'`)

* `DATA_PLANE_DELETE` (value: `'data_plane_delete'`)

* `DATA_PLANE_UPDATE` (value: `'data_plane_update'`)

* `DATA_PLANE_READ` (value: `'data_plane_read'`)

* `DATA_PLANE_REGENERATE_CREDS` (value: `'data_plane_regenerate_creds'`)

* `DATA_PLANE_LIST_ASSOCIATIONS` (value: `'data_plane_list_associations'`)

* `DATA_PLANE_JOBS_DEQUEUE_NEXT` (value: `'data_plane_jobs_dequeue_next'`)

* `DATA_PLANE_ASSOCIATION_DELETE` (value: `'data_plane_association_delete'`)

* `ALERT_RULE_READ` (value: `'alert_rule_read'`)

* `ALERT_RULE_UPDATE` (value: `'alert_rule_update'`)

* `ALERT_RULE_DELETE` (value: `'alert_rule_delete'`)

* `MODEL_ALERT_READ` (value: `'model_alert_read'`)

* `WEBHOOK_READ` (value: `'webhook_read'`)

* `WEBHOOK_UPDATE` (value: `'webhook_update'`)

* `WEBHOOK_DELETE` (value: `'webhook_delete'`)

* `ROLE_READ` (value: `'role_read'`)

* `CUSTOM_AGGREGATION_READ` (value: `'custom_aggregation_read'`)

* `CUSTOM_AGGREGATION_PUT` (value: `'custom_aggregation_put'`)

* `CUSTOM_AGGREGATION_DELETE` (value: `'custom_aggregation_delete'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


